@@ -16,10 +16,251 @@ from . import probabilities as prob
 from .errors import KineticlibError
 
 
+def crosssection_elastic(g: float, T: float, idata: np.ndarray, rig_sphere: bool=False) -> float:
+    """
+    Calculates the VSS or rigid sphere crosssection
+
+    Parameters
+    ----------
+    g : float
+        the dimensionless relative velocity of the particles
+    T : float
+        the temperature of the mixture
+    idata : 1-D array-like
+        the array of interaction data
+    rig_sphere : bool
+        if ``True``, the rigid sphere crosssection is calculated, if ``False``, the VSS crosssection is calculated,
+        defaults to ``False``
+
+    Returns
+    -------
+        The VSS or rigid sphere crosssection
+    """
+    if rig_sphere:
+        return raw_crosssection_rigid_sphere(idata[1])
+    else:
+        return raw_crosssection_VSS(g, T, idata[9], idata[10])
+
+
+def crosssection_vt(g: float, T: float, idata: np.ndarray, molecule: MoleculeSTS, i: int, delta: int,
+                    rig_sphere: bool=False) -> float:
+    """Calculates the VT crosssection using the FHO probability and VSS or
+    rigid sphere cross-section models for the following process: **M(i) + P -> M(i + delta) + P**
+
+    Parameters
+    ----------
+    g : float
+        the dimensionless relative velocity of the particles
+    T : float
+        the temperature of the mixture
+    idata : 1-D array-like
+        the array of interaction data
+    molecule : MoleculeSTS or Molecule
+        the molecule which undergoes the VT transition
+    i : int
+        the vibrational level of the molecule undergoing the transition
+    delta : int
+        the change in vibrational level of the molecule
+    rig_sphere : bool, optional
+        if ``True``, the rigid sphere model is used for the crosssection, if ``False``, the VSS is model is used,
+        defaults to ``False``
+
+    Returns
+    -------
+    float
+        The VT crosssection
+
+    Raises
+    ------
+    KineticlibError
+        if ``delta == 0``
+    """
+    if delta != 0:
+        return raw_crosssection_vt(g, T, idata[1], idata[0], idata[4], idata[9], idata[10], molecule.vibr[i],
+                                   molecule.vibr[i + delta], molecule.vibr_zero, molecule.diss,
+                                   i, delta, rig_sphere)
+    else:
+        raise KineticlibError('VT transition with no change in vibrational level specified')
+
+
+def crosssection_vv(g: float, T: float, idata: np.ndarray, molecule1: MoleculeSTS, molecule2: MoleculeSTS, i: int,
+                    k: int, i_delta: int, rig_sphere: bool=False) -> float:
+    """Calculates the VV crosssection using the FHO probability and VSS or
+    rigid sphere cross-section models for the following process:
+    **M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)**
+
+    Parameters
+    ----------
+    g : float
+        the dimensionless relative velocity of the particles
+    T : float
+        the temperature of the mixture
+    idata : 1-D array-like
+        the array of interaction data
+    molecule1 : MoleculeSTS or Molecule
+        the molecule M1
+    molecule2 : MoleculeSTS or Molecule
+        the molecule M2
+    i : int
+        the vibrational level of molecule M1
+    k : int
+        the vibrational level of molecule M2
+    i_delta : int
+        the change in vibrational level of molecule M1
+    rig_sphere : bool, optional
+        if ``True``, the rigid sphere model is used for the crosssection, if ``False``, the VSS is model is used,
+        defaults to ``False``
+
+    Returns
+    -------
+    float
+        The VV crosssection
+
+    Raises
+    ------
+    KineticlibError
+        if ``i_delta == 0``
+    """
+    if i_delta != 0:
+        return raw_crosssection_vv(g, T, idata[1], idata[0], idata[4], idata[9], idata[10],
+                                   molecule1.vibr[i], molecule1.vibr[i + i_delta],
+                                   molecule2.vibr[k], molecule2.vibr[k - i_delta], i, k, i_delta, rig_sphere)
+    else:
+        raise KineticlibError('VV transition with no change in vibrational level specified')
+
+
+def crosssection_diss_rigid_sphere(g: float, T: float, idata: np.ndarray, molecule: MoleculeSTS, i: int,
+                                   center_of_mass: bool=True, vl_dependent: bool=True) -> float:
+    """Calculates the dissociation crosssection either using the rigid sphere model or the rigid sphere
+    model depending on the relative energy along the center-of-mass line for the process
+    **AB(i) + P -> A + B + P**
+
+    Parameters
+    ----------
+    g : float
+        the dimensionless relative velocity of the particles
+    T : float
+        the temperature of the mixture
+    idata : 1-D array-like
+        the array of interaction data
+    molecule : Molecule
+        the molecule which dissociates
+    i : int
+        the vibrational level from which the molecule dissociates (if ``vl_dependent``
+        is ``False``, can be any value)
+    center_of_mass : bool, optional
+        if ``True``, the kinetic energy of the collision partners will be calculated along the center-of-mass line,
+        if ``False``, the total kinetic energy will be used, defaults to ``True``
+    vl_dependent : bool, optional
+        if ``True``, the dissociation crosssection takes into account the vibrational energy of the dissociating
+        molecule, if ``False``, the crosssection is independent of the vibrational energy, defaults to ``True``
+
+    Returns
+    -------
+    float
+        The dissociation crosssection
+    """
+    return raw_crosssection_diss_rigid_sphere(g, T, idata[1], molecule.vibr[i], molecule.diss, center_of_mass, vl_dependent)
+
+
+def vt_integral(T: float, deg: int, idata: np.ndarray, molecule: MoleculeSTS, i: int, delta: int,
+                rig_sphere: bool=False, nokt: bool=False) -> float:
+    """Calculates the generalized VT omega integral using the FHO probability and VSS or
+    rigid sphere cross-section models for the following process: **M(i) + P -> M(i + delta) + P**
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    deg : int
+        the degree of the omega integral
+    idata : 1-D array-like
+        the array of interaction data
+    molecule : MoleculeSTS or Molecule
+        the molecule which undergoes the VT transition
+    i : int
+        the vibrational level of the molecule undergoing the transition
+    delta : int
+        the change in vibrational level of the molecule
+    rig_sphere : bool, optional
+        if ``True``, the rigid sphere model is used for the crosssection, if ``False``, the VSS is model is used,
+        defaults to ``False``
+    nokt : bool, optional
+        if ``True``, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to ``False``
+
+    Returns
+    -------
+    float
+        The generalized omega integral over the VT crosssection
+
+    Raises
+    ------
+    KineticlibError
+        if ``delta == 0``
+    """
+    if not rig_sphere:
+        return raw_vt_integral(T, deg, idata[0], idata[4], idata[9], idata[10], molecule.vibr[i],
+                               molecule.vibr[i + delta], molecule.vibr_zero, molecule.diss, i, delta, nokt)
+    else:
+        return raw_vt_integral_rigid_sphere(T, deg, idata[1], idata[0], idata[4], molecule.vibr[i],
+                                            molecule.vibr[i + delta], molecule.vibr_zero, molecule.diss, i, delta, nokt)
+
+
+def vv_integral(T: float, deg: int, idata: np.ndarray, molecule1: MoleculeSTS, molecule2: MoleculeSTS, i: int,
+                k: int, i_delta: int, rig_sphere: bool=False, nokt=False) -> float:
+    """Calculates the generalized VV omega integral using the FHO probability and VSS or
+    rigid sphere cross-section models for the following process:
+    **M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)**
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    deg : int
+        the degree of the omega integral
+    idata : 1-D array-like
+        the array of interaction data
+    molecule1 : MoleculeSTS or Molecule
+        the molecule M1
+    molecule2 : MoleculeSTS or Molecule
+        the molecule M2
+    i : int
+        the vibrational level of molecule M1
+    k : int
+        the vibrational level of molecule M2
+    i_delta : int
+        the change in vibrational level of molecule M1
+    rig_sphere : bool, optional
+        if ``True``, the rigid sphere model is used for the crosssection, if ``False``, the VSS is model is used,
+        defaults to ``False``
+    nokt : bool, optional
+        if ``True``, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to ``False``
+
+    Returns
+    -------
+    float
+        The generalized omega integral over the VV crosssection
+
+    Raises
+    ------
+    KineticlibError
+        if ``i_delta == 0``
+    """
+    if not rig_sphere:
+        return raw_vv_integral(T, deg, idata[0], idata[4], idata[9], idata[10],
+                               molecule1.vibr[i], molecule1.vibr[i + i_delta],
+                               molecule2.vibr[k], molecule2.vibr[k - i_delta], i, k, i_delta, nokt)
+    else:
+        raw_vv_integral_rigid_sphere(T, deg, idata[1], idata[0], idata[4],
+                                     molecule1.vibr[i], molecule1.vibr[i + i_delta],
+                                     molecule2.vibr[k], molecule2.vibr[k - i_delta], i, k, i_delta, nokt)
+
+
 def diss_integral_rigid_sphere(T: float, deg: int, idata: np.ndarray, molecule: MoleculeSTS, i: int,
                                center_of_mass: bool=True, vl_dependent: bool=True, nokt: bool=False) -> float:
     """Calculates the generalized dissociation omega integral either using the rigid sphere model or the rigid sphere
-    model depending on the relative energy along the center-of-mass line
+    model depending on the relative energy along the center-of-mass line for the process
+    **AB(i) + P -> A + B + P**
 
     Parameters
     ----------
@@ -82,101 +323,6 @@ def elastic_integral(T: float, deg: int, idata: np.ndarray, rig_sphere: bool=Fal
     return raw_elastic_integral(T, deg, idata[1], idata[0], idata[9], idata[10], rig_sphere, nokt)
 
 
-def vt_integral(T: float, deg: int, idata: np.ndarray, molecule: MoleculeSTS, i: int, delta: int,
-                rig_sphere: bool=False, nokt: bool=False) -> float:
-    """Calculates the generalized VT omega integral using the FHO probability and VSS or
-    rigid sphere cross-section models for the following process: **M(i) + P -> M(i + delta) + P**
-
-    Parameters
-    ----------
-    T : float
-        the temperature of the mixture
-    deg : int
-        the degree of the omega integral
-    idata : 1-D array-like
-        the array of interaction data
-    molecule : MoleculeSTS or Molecule
-        the molecule which undergoes the VT transition
-    i : int
-        the vibrational level of the molecule undergoing the transition
-    delta : int
-        the change in vibrational level of the molecule
-    rig_sphere : bool, optional
-        if ``True``, the rigid sphere model is used for the crosssection, if ``False``, the VSS is model is used,
-        defaults to ``False``
-    nokt : bool, optional
-        if ``True``, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to ``False``
-
-    Returns
-    -------
-    float
-        The generalized omega integral over the VT crosssection
-
-    Raises
-    ------
-    KineticlibError
-        if ``delta == 0``
-    
-    """
-    if not rig_sphere:
-        return raw_vt_integral(T, deg, idata[0], idata[4], idata[9], idata[10], molecule.vibr[i],
-                               molecule.vibr[i + delta], molecule.vibr_zero, molecule.diss, i, delta, nokt)
-    else:
-        return raw_vt_integral_rigid_sphere(T, deg, idata[1], idata[0], idata[4], molecule.vibr[i],
-                                            molecule.vibr[i + delta], molecule.vibr_zero, molecule.diss, i, delta, nokt)
-
-
-def vv_integral(T: float, deg: int, idata: np.ndarray, molecule1: MoleculeSTS, molecule2: MoleculeSTS, i: int,
-                k: int, i_delta: int, rig_sphere: bool=False, nokt=False) -> float:
-    """Calculates the generalized VV omega integral using the FHO probability and VSS or
-    rigid sphere cross-section models for the following process:
-    **M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)**
-
-    Parameters
-    ----------
-    T : float
-        the temperature of the mixture
-    deg : int
-        the degree of the omega integral
-    idata : 1-D array-like
-        the array of interaction data
-    molecule1 : MoleculeSTS or Molecule
-        the molecule M1
-    molecule2 : MoleculeSTS or Molecule
-        the molecule M2
-    i : int
-        the vibrational level of molecule M1
-    k : int
-        the vibrational level of molecule M2
-    i_delta : int
-        the change in vibrational level of molecule M1
-    rig_sphere : bool, optional
-        if ``True``, the rigid sphere model is used for the crosssection, if ``False``, the VSS is model is used,
-        defaults to ``False``
-    nokt : bool, optional
-        if ``True``, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to ``False``
-
-    Returns
-    -------
-    float
-        The generalized omega integral over the VV crosssection
-
-    Raises
-    ------
-    KineticlibError
-        if ``i_delta == 0``
-    
-    """
-    if not rig_sphere:
-        return raw_vv_integral(T, deg, idata[0], idata[4], idata[9], idata[10],
-                               molecule1.vibr[i], molecule1.vibr[i + i_delta],
-                               molecule2.vibr[k], molecule2.vibr[k - i_delta], i, k, i_delta, nokt)
-    else:
-        raw_vv_integral_rigid_sphere(T, deg, idata[1], idata[0], idata[4],
-                                     molecule1.vibr[i], molecule1.vibr[i + i_delta],
-                                     molecule2.vibr[k], molecule2.vibr[k - i_delta], i, k, i_delta, nokt)
-
-
 def vv_collisions(T: float, T1_1: float, T1_2: float, idata: np.ndarray, molecule1: Molecule, molecule2: Molecule,
                   rig_sphere: bool=False, nokt: bool=False) -> np.ndarray:
     """Calculates the averaging :math:`\\left<F \\right>^{VV}_{cd}` over all one-quantum VV crosssections of the type
@@ -386,22 +532,156 @@ def dE_rot_dE_rot_full(T: float, idata: np.ndarray, molecule1: MoleculeSTS, mole
                                   molecule2.num_rot, full_integral, rig_sphere, nokt)
 
 
-def raw_diss_integral_rigid_sphere(T: float, deg: int, sigma: float, mass: float, molecule_vibr: float,
-                                   molecule_diss: float, center_of_mass: bool=True, vl_dependent: bool=True,
-                                   nokt: bool=False) -> float:
-    """Calculates the generalized dissociation omega integral either using the rigid sphere model or the rigid sphere
-    model depending on the relative energy along the center-of-mass line, *raw* version
+def raw_crosssection_VSS(g: float, T: float, vssc: float, vsso: float) -> float:
+    """Calculates the VSS crosssection, *raw* version
 
     Parameters
     ----------
+    g : float
+        the dimensionless relative velocity of the particles
+    T : float
+        the temperature of the mixture
+    vssc : float
+        the elastic crosssection VSS potential :math:`C` parameter
+    vsso : float
+        the elastic crosssection VSS potential :math:`\\omega` parameter
+
+    Returns
+    -------
+        The VSS crosssection
+    """
+    return vssc * (T ** (-vsso)) * (g ** (2 - vsso))
+
+
+def raw_crosssection_rigid_sphere(sigma: float) -> float:
+    """Calculates the rigid sphere crosssection, *raw* version
+
+    Parameters
+    ----------
+    sigma : float
+        the collision diameter :math:`\\sigma_{cd}`
+
+    Returns
+    -------
+    float
+        The rigid sphere crosssection
+    """
+    return constants.pi * (sigma ** 2)
+
+
+def raw_crosssection_vt(g: float, T: float, sigma: float, mass: float, beta: float, vssc: float, vsso: float,
+                        ve_before: float, ve_after: float, molecule_vibr_zero: float, molecule_diss: float, i: int,
+                        delta: int, rig_sphere: bool=False) -> float:
+    """Calculates the VT crosssection using the FHO probability and VSS or rigid sphere models
+    for the following process: **M(i) + P -> M(i + delta) + P**, *raw* version
+
+    Parameters
+    ----------
+    g : float
+        the dimensionless relative velocity of the particles
     T : float
         the temperature of the mixture
-    deg : int
-        the degree of the omega integral
     sigma : float
         the collision diameter :math:`\\sigma_{cd}`
     mass : float
         the collision-reduced mass :math:`m_{cd}`
+    beta : float
+        the IPL potential :math:`\\beta` parameter
+    vssc : float
+        the elastic crosssection VSS potential :math:`C` parameter
+    vsso : float
+        the elastic crosssection VSS potential :math:`\\omega` parameter
+    ve_before : float
+        the vibrational energy of the molecule before the transition
+    ve_after : float
+        the vibrational energy of the molecule after the transition
+    molecule_vibr_zero : float
+        the energy of the 0-th vibrational level
+    molecule_diss : float
+        the dissociation energy of the molecule which undergoes the transition
+    i : int
+        the vibrational level of the molecule
+    delta : int
+        the change in the vibrational level of the molecule
+
+    Returns
+    -------
+    float
+        The VT crosssection
+    """
+    if rig_sphere:
+        return prob.vt_probability(g, T, mass, beta, ve_before, ve_after, molecule_vibr_zero, molecule_diss, i, delta)\
+               * raw_crosssection_rigid_sphere(sigma)
+    else:
+        return prob.vt_probability(g, T, mass, beta, ve_before, ve_after, molecule_vibr_zero, molecule_diss, i, delta)\
+               * raw_crosssection_VSS(g, T, vssc, vsso)
+
+
+def raw_crosssection_vv(g, T: float, sigma: float, mass: float, beta: float, vssc: float, vsso: float,
+                        ve_before1: float, ve_after1: float, ve_before2: float, ve_after2: float, i: int, k: int,
+                        i_delta: int, rig_sphere: bool=False) -> float:
+    """Calculates the VV crosssection using the FHO probability and VSS or rigid sphere models
+    for the following process: **M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)**, *raw* version
+
+    Parameters
+    ----------
+    g : float
+        the dimensionless relative velocity of the particles
+    T : float
+        the temperature of the mixture
+    sigma : float
+        the collision diameter :math:`\\sigma_{cd}`
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    beta : float
+        the IPL potential :math:`\\beta` parameter
+    vssc : float
+        the elastic crosssection VSS potential :math:`C` parameter
+    vsso : float
+        the elastic crosssection VSS potential :math:`\\omega` parameter
+    ve_before1 : float
+        the vibrational energy of the molecule M1 before the transition
+    ve_after1 : float
+        the vibrational energy of the molecule M1 after the transition
+    ve_before2 : float
+        the vibrational energy of the molecule M2 before the transition
+    ve_after2 : float
+        the vibrational energy of the molecule M2 after the transition
+    i : int
+        the vibrational level of molecule M1
+    k : int
+        the vibrational level of molecule M2
+    i_delta : int
+        the change in vibrational level of molecule M1
+
+    Returns
+    -------
+    float
+        The VV crosssection
+    """
+    if rig_sphere:
+        return prob.vv_probability(g, T, mass, beta, ve_before1, ve_after1, ve_before2, ve_after2, i, k, i_delta)\
+               * raw_crosssection_rigid_sphere(sigma)
+    else:
+        return prob.vv_probability(g, T, mass, beta, ve_before1, ve_after1, ve_before2, ve_after2, i, k, i_delta)\
+               * raw_crosssection_VSS(g, T, vssc, vsso)
+
+
+def raw_crosssection_diss_rigid_sphere(g: float, T: float, sigma: float, molecule_vibr: float,
+                                       molecule_diss: float, center_of_mass: bool=True,
+                                       vl_dependent: bool=True) -> float:
+    """Calculates the dissociation crosssection either using the rigid sphere model or the rigid sphere
+    model depending on the relative energy along the center-of-mass line for the process
+    **AB(i) + P -> A + B + P**, *raw* version
+
+    Parameters
+    ----------
+    g : float
+        the dimensionless relative velocity of the particles
+    T : float
+        the temperature of the mixture
+    sigma : float
+        the collision diameter :math:`\\sigma_{cd}`
     molecule_vibr : float
         the dimensional vibrational energy of the level from which the molecule dissociates (if ``vl_dependent``
         is ``False``, can be any value)
@@ -413,43 +693,29 @@ def raw_diss_integral_rigid_sphere(T: float, deg: int, sigma: float, mass: float
     vl_dependent : bool, optional
         if ``True``, the dissociation crosssection takes into account the vibrational energy of the dissociating
         molecule, if ``False``, the crosssection is independent of the vibrational energy, defaults to ``True``
-    nokt : bool, optional
-        if ``True``, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to ``False``
 
     Returns
     -------
     float
-        The generalized omega integral over the dissociation crosssection
-
-    Raises
-    ------
-    KineticlibError
-        if ``deg > 1``
+        The dissociation crosssection
     """
-    if not nokt:
-        multiplier = constants.pi * (sigma ** 2) * ((constants.k * T / (2 * constants.pi * mass)) ** 0.5)
-    else:
-        multiplier = constants.pi * (sigma ** 2) * ((0.5 / (constants.pi * mass)) ** 0.5)
     if vl_dependent:
-        min_sq = (molecule_diss - molecule_vibr) / (constants.k * T)
+        min_sq = molecule_vibr + constants.k * T * (g ** 2)
     else:
-        min_sq = molecule_diss / (constants.k * T)
-    if deg == 0:
-        if not center_of_mass:
-            return 0.5 * multiplier * np.exp(-min_sq)
-        else:
-            return 0.5 * multiplier * (min_sq + 1.0) * np.exp(-min_sq)
-    elif deg == 1:
-        if not center_of_mass:
-            return 0.5 * multiplier * (min_sq + 2.0) * np.exp(-min_sq)
-        else:
-            return 0.5 * multiplier * ((min_sq ** 2) + 2.0 * min_sq + 1.0) * np.exp(-min_sq)
+        min_sq = constants.k * T * (g ** 2)
+
+    if min_sq < molecule_diss:
+        return 0.0
     else:
-        raise KineticlibError('Cannot calculated generalized dissociation omega integral of degree ' + str(deg))
+        if center_of_mass:
+            return constants.pi * (sigma ** 2) * (1.0 - molecule_diss / min_sq)
+        else:
+            return constants.pi * (sigma ** 2)
 
 
-def elastic_crosssection(g: float, deg: int, vsso: float) -> float:
-    """Calculates the velocity-dependent part of the generalized elastic omega integral for the VSS model
+def elastic_omega_g_only_vss(g: float, deg: int, vsso: float) -> float:
+    """Calculates the velocity-dependent part of the integrand of the
+    generalized elastic omega integral for the VSS model
 
     Parameters
     ----------
@@ -458,18 +724,19 @@ def elastic_crosssection(g: float, deg: int, vsso: float) -> float:
     deg : int
         the degree of the omega integral
     vsso : float
-        the omega parameter in the VSS model
+        the elastic crosssection VSS potential :math:`\\omega` parameter
 
     Returns
     -------
     float
-        The velocity-dependent part of the generalized omega integral
+        The velocity-dependent part of the integrand of the generalized omega integral
     """
     return np.exp(-(g ** 2)) * (g ** (3 + 2 * (deg - vsso)))
 
 
-def elastic_crosssection_rigid_sphere(g: float, deg: int) -> float:
-    """Calculates the velocity-dependent part of the generalized elastic omega integral for the rigid-sphere model
+def elastic_omega_g_only_rigid_sphere(g: float, deg: int) -> float:
+    """Calculates the velocity-dependent part of the integrand of the
+    generalized elastic omega integral for the rigid-sphere model
 
     Parameters
     ----------
@@ -481,52 +748,11 @@ def elastic_crosssection_rigid_sphere(g: float, deg: int) -> float:
     Returns
     -------
     float
-        The velocity-dependent part of the generalized omega integral
+        The velocity-dependent part of the integrand of the generalized omega integral
     """
     return np.exp(-(g ** 2)) * (g ** (3 + 2 * deg))
 
 
-def raw_elastic_integral(T: float, deg: int, sigma: float, mass: float, vssc: float, vsso: float,
-                         rig_sphere: bool=False, nokt: bool=False) -> float:
-    """Calculates the generalized elastic omega integral either using the rigid sphere model or the VSS model,
-    *raw* version
-
-    Parameters
-    ----------
-    T : float
-        the temperature of the mixture
-    deg : int
-        the degree of the omega integral
-    sigma : float
-        the collision diameter :math:`\\sigma_{cd}`
-    mass : float
-        the collision-reduced mass :math:`m_{cd}`
-    vssc : float
-        the elastic crosssection VSS potential :math:`C` parameter
-    vsso : float
-        the elastic crosssection VSS potential :math:`\\omega` parameter
-    rig_sphere : bool, optional
-        if ``True``, the rigid sphere model is used for the crosssection, if ``False``,
-        the VSS model is used, defaults to ``False``
-    nokt : bool, optional
-        if ``True``, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to ``False``
-
-    Returns
-    -------
-    float
-        The generalized omega integral over the elastic crosssection
-    """
-    if not nokt:
-        multiplier = ((T * constants.k / (2.0 * constants.pi * mass)) ** 0.5)
-    else:
-        multiplier = ((0.5 / (constants.pi * mass)) ** 0.5)
-    if not rig_sphere:
-        return 0.5 * multiplier * gamma(2.0 - vsso + deg) * (constants.physical_constants['Angstrom star'][0] ** 2)\
-                   * vssc * (T ** (-vsso))
-    else:
-        return 0.5 * multiplier * constants.pi * gamma(0.5 * deg + 2.0) * (sigma ** 2)
-
-
 def raw_vt_integral(T: float, deg: int, mass: float, beta: float, vssc: float, vsso: float,
                     ve_before: float, ve_after: float, molecule_vibr_zero: float, molecule_diss: float, i: int,
                     delta: int, nokt: bool=False) -> float:
@@ -574,9 +800,10 @@ def raw_vt_integral(T: float, deg: int, mass: float, beta: float, vssc: float, v
 
     """
     if delta != 0:
+        molecule_depth = molecule_vibr_zero + molecule_diss
         f = lambda g: prob.vt_prob_g_only(g, T, mass, beta, ve_before, ve_after,
-                                          i, delta, molecule_vibr_zero + molecule_diss)\
-                      * elastic_crosssection(g, deg, vsso)
+                                          i, delta, molecule_depth)\
+                      * elastic_omega_g_only_vss(g, deg, vsso)
         if delta == 1:
             mult = (i + 1)
         elif delta == -1:
@@ -637,9 +864,10 @@ def raw_vt_integral_rigid_sphere(T: float, deg: int, sigma: float, mass: float,
 
     """
     if delta != 0:
+        molecule_depth = molecule_vibr_zero + molecule_diss
         f = lambda g: prob.vt_prob_g_only(g, T, mass, beta, ve_before, ve_after,
-                                          i, delta, molecule_vibr_zero + molecule_diss)\
-                      * elastic_crosssection_rigid_sphere(g, deg)
+                                          i, delta, molecule_depth)\
+                      * elastic_omega_g_only_rigid_sphere(g, deg)
         if delta == 1:
             mult = (i + 1)
         elif delta == -1:
@@ -707,7 +935,7 @@ def raw_vv_integral(T: float, deg: int, mass: float, beta: float, vssc: float, v
     """
     if i_delta != 0:
         f = lambda g: prob.vv_prob_g_only(g, T, mass, beta, ve_before1, ve_after1, ve_before2, ve_after2,
-                                          i, k, i_delta) * elastic_crosssection(g, deg, vsso)
+                                          i, k, i_delta) * elastic_omega_g_only_vss(g, deg, vsso)
         if i_delta == 1:
             mult = (i + 1) * k
         elif i_delta == -1:
@@ -777,7 +1005,7 @@ def raw_vv_integral_rigid_sphere(T: float, deg: int, sigma: float, mass: float,
     """
     if i_delta != 0:
         f = lambda g: prob.vv_prob_g_only(g, T, mass, beta, ve_before1, ve_after1, ve_before2,
-                                          ve_after2, i, k, i_delta) * elastic_crosssection_rigid_sphere(g, deg)
+                                          ve_after2, i, k, i_delta) * elastic_omega_g_only_rigid_sphere(g, deg)
         if i_delta == 1:
             mult = (i + 1) * k
         elif i_delta == -1:
@@ -795,6 +1023,109 @@ def raw_vv_integral_rigid_sphere(T: float, deg: int, sigma: float, mass: float,
         raise KineticlibError('VV transition with no change in vibrational level specified')
 
 
+def raw_diss_integral_rigid_sphere(T: float, deg: int, sigma: float, mass: float, molecule_vibr: float,
+                                   molecule_diss: float, center_of_mass: bool=True, vl_dependent: bool=True,
+                                   nokt: bool=False) -> float:
+    """Calculates the generalized dissociation omega integral either using the rigid sphere model or the rigid sphere
+    model depending on the relative energy along the center-of-mass line, *raw* version
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    deg : int
+        the degree of the omega integral
+    sigma : float
+        the collision diameter :math:`\\sigma_{cd}`
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    molecule_vibr : float
+        the dimensional vibrational energy of the level from which the molecule dissociates (if ``vl_dependent``
+        is ``False``, can be any value)
+    molecule_diss : float
+        the dissociation energy of the molecule which dissociates
+    center_of_mass : bool, optional
+        if ``True``, the kinetic energy of the collision partners will be calculated along the center-of-mass line,
+        if ``False``, the total kinetic energy will be used, defaults to ``True``
+    vl_dependent : bool, optional
+        if ``True``, the dissociation crosssection takes into account the vibrational energy of the dissociating
+        molecule, if ``False``, the crosssection is independent of the vibrational energy, defaults to ``True``
+    nokt : bool, optional
+        if ``True``, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to ``False``
+
+    Returns
+    -------
+    float
+        The generalized omega integral over the dissociation crosssection
+
+    Raises
+    ------
+    KineticlibError
+        if ``deg > 1``
+    """
+    if not nokt:
+        multiplier = constants.pi * (sigma ** 2) * ((constants.k * T / (2 * constants.pi * mass)) ** 0.5)
+    else:
+        multiplier = constants.pi * (sigma ** 2) * ((0.5 / (constants.pi * mass)) ** 0.5)
+    if vl_dependent:
+        min_sq = (molecule_diss - molecule_vibr) / (constants.k * T)
+    else:
+        min_sq = molecule_diss / (constants.k * T)
+    if deg == 0:
+        if not center_of_mass:
+            return 0.5 * multiplier * np.exp(-min_sq)
+        else:
+            return 0.5 * multiplier * (min_sq + 1.0) * np.exp(-min_sq)
+    elif deg == 1:
+        if not center_of_mass:
+            return 0.5 * multiplier * (min_sq + 2.0) * np.exp(-min_sq)
+        else:
+            return 0.5 * multiplier * ((min_sq ** 2) + 2.0 * min_sq + 1.0) * np.exp(-min_sq)
+    else:
+        raise KineticlibError('Cannot calculated generalized dissociation omega integral of degree ' + str(deg))
+
+
+def raw_elastic_integral(T: float, deg: int, sigma: float, mass: float, vssc: float, vsso: float,
+                         rig_sphere: bool=False, nokt: bool=False) -> float:
+    """Calculates the generalized elastic omega integral either using the rigid sphere model or the VSS model,
+    *raw* version
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    deg : int
+        the degree of the omega integral
+    sigma : float
+        the collision diameter :math:`\\sigma_{cd}`
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    vssc : float
+        the elastic crosssection VSS potential :math:`C` parameter
+    vsso : float
+        the elastic crosssection VSS potential :math:`\\omega` parameter
+    rig_sphere : bool, optional
+        if ``True``, the rigid sphere model is used for the crosssection, if ``False``,
+        the VSS model is used, defaults to ``False``
+    nokt : bool, optional
+        if ``True``, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to ``False``
+
+    Returns
+    -------
+    float
+        The generalized omega integral over the elastic crosssection
+    """
+    if not nokt:
+        multiplier = ((T * constants.k / (2.0 * constants.pi * mass)) ** 0.5)
+    else:
+        multiplier = ((0.5 / (constants.pi * mass)) ** 0.5)
+    if not rig_sphere:
+        return 0.5 * multiplier * gamma(2.0 - vsso + deg) * (constants.physical_constants['Angstrom star'][0] ** 2)\
+                   * vssc * (T ** (-vsso))
+    else:
+        return 0.5 * multiplier * constants.pi * gamma(0.5 * deg + 2.0) * (sigma ** 2)
+
+
 def raw_vv_collisions(T: float, sigma: float, mass: float, beta: float, vssc: float, vsso: float,
                       Z_vibr1: float, Z_vibr2: float,
                       molecule_vibr_array1: np.ndarray, molecule_vibr_array2: np.ndarray,
