@@ -40,8 +40,8 @@ def fact_div_fact(start: int, end: int) -> float:
 
 
 def vel_avg_vt(g: float, ve_before: float, ve_after: float, m: float) -> float:
-    """Helper function, returns the arithmetic mean of the relative velocity of particles before and after
-    a VT transition (using the energy conservation law) M(i1) + P -> M(i2) + P
+    """Returns the arithmetic mean of the relative velocity of particles before and after
+    a VT transition (using the energy conservation law) **M(i1) + P -> M(i2) + P**
 
     Parameters
     ----------
@@ -72,8 +72,8 @@ def vel_avg_vt(g: float, ve_before: float, ve_after: float, m: float) -> float:
 
 
 def vel_avg_vv(g: float, ve_before1: float, ve_after1: float, ve_before2: float, ve_after2: float, m: float) -> float:
-    """Helper function, returns the arithmetic mean of the relative velocity of particles before and after
-    a VV transition (using the energy conservation law) M1(i1) + M2(k1) -> M1(i2) + M2(k2)
+    """Returns the arithmetic mean of the relative velocity of particles before and after
+    a VV transition (using the energy conservation law) **M1(i1) + M2(k1) -> M1(i2) + M2(k2)**
 
     Parameters
     ----------
@@ -110,7 +110,7 @@ def vel_avg_vv(g: float, ve_before1: float, ve_after1: float, ve_before2: float,
 def vt_probability(g: float, T: float, mass: float, beta: float, ve_before: float, ve_after: float,
                    molecule_vibr_zero: float, molecule_diss: float, i: int, delta: int) -> float:
     """Returns the probability of a VT transition using the FHO (Forced harmonic oscillator) model
-     M(i) + P -> M(i + delta) + P
+    **M(i) + P -> M(i + delta) + P**
 
     Parameters
     ----------
@@ -121,7 +121,7 @@ def vt_probability(g: float, T: float, mass: float, beta: float, ve_before: floa
     mass : float
         the collision-reduced mass :math:`m_{cd}`
     beta : float
-        the IPL :math:`\\beta` parameter
+        the IPL potential :math:`\\beta` parameter
     ve_before : float
         the vibrational energy of the molecule before the transition
     ve_after : float
@@ -167,7 +167,7 @@ def vt_probability(g: float, T: float, mass: float, beta: float, ve_before: floa
 def vt_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before: float, ve_after: float, i: int, delta: int,
                    depth: float) -> float:
     """Returns the velocity-dependent part of the probability of a VT transition using
-    the FHO (Forced harmonic oscillator) model M(i) + P -> M(i + delta) + P
+    the FHO (Forced harmonic oscillator) model **M(i) + P -> M(i + delta) + P**
 
     Parameters
     ----------
@@ -178,7 +178,7 @@ def vt_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before: floa
     mass : float
         the collision-reduced mass :math:`m_{cd}`
     beta : float
-        the IPL :math:`\\beta` parameter
+        the IPL potential :math:`\\beta` parameter
     ve_before : float
         the vibrational energy of the molecule before the transition
     ve_after : float
@@ -240,7 +240,7 @@ def vt_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before: floa
 def vv_probability(g: float, T: float, mass: float, beta: float, ve_before1: float, ve_after1: float,
                    ve_before2: float, ve_after2: float, i: int, k: int, i_delta: int) -> float:
     """Returns the probability of a VV transition using the FHO (Forced harmonic oscillator) model
-     M1(i) + M2(k) -> M1(i + delta) + M2(k - i_delta)
+    **M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)**
 
     Parameters
     ----------
@@ -261,11 +261,11 @@ def vv_probability(g: float, T: float, mass: float, beta: float, ve_before1: flo
     ve_after2 : float
         the vibrational energy of the molecule M2 after the transition
     i : int
-        the vibrational level of molecule1
+        the vibrational level of molecule M1
     k : int
-        the vibrational level of molecule2
+        the vibrational level of molecule M2
     i_delta : int
-        the change in vibrational level of the first molecule
+        the change in vibrational level of the molecule M1
 
     Returns
     -------
@@ -306,7 +306,7 @@ def vv_probability(g: float, T: float, mass: float, beta: float, ve_before1: flo
 def vv_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before1: float, ve_after1: float,
                    ve_before2: float, ve_after2: float, i: int, k: int, i_delta: int) -> float:
     """Returns the velocity-dependent part of the probability of a VV transition using the FHO
-    (Forced harmonic oscillator) model M1(i) + M2(k) -> M1(i + delta) + M2(k - i_delta)
+    (Forced harmonic oscillator) model **M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)**
 
     Parameters
     ----------
@@ -327,11 +327,11 @@ def vv_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before1: flo
     ve_after2 : float
         the vibrational energy of the molecule M2 after the transition
     i : int
-        the vibrational level of molecule1
+        the vibrational level of molecule M1
     k : int
-        the vibrational level of molecule2
+        the vibrational level of molecule M2
     i_delta : int
-        the change in vibrational level of the first molecule
+        the change in vibrational level of the molecule M1
 
     Returns
     -------
